
<li class="text-xs">
    {% if link %}
        <a href="{{ link }}">{{ name }}</a> <span class="mx-2 text-base-200 dark:text-base-600">/</span>
    {% else %}
        {{ name }}
    {% endif %}
</li>
